Struct slice_cell::SliceCell

source ·
#[repr(transparent)]
pub struct SliceCell<T> { /* private fields */ }
A Cell<[T]>-like type that has some additional slice-like API.

References to this type can be gotten from dereferencing an ArrayCell<T, N>, or using from_mut.

Under the assume_cell_layout cargo feature, this type can be converted to and from Cell<[T]> and [Cell<T>] in several ways.

Implementations

View this SliceCell as a Cell of a slice.

View this SliceCell as a slice of Cells.

View a Cell of a slice as a SliceCell.

View a slice Cells as a SliceCell.

View this SliceCell as a Cell of a slice.

View this SliceCell as a slice of Cells.

View a Cell of a slice as a SliceCell.

View this SliceCell as a Cell of a slice.

View this SliceCell as a slice of Cells.

View a Cell of a slice as a SliceCell.

View this SliceCell as a Cell of a slice.

View this SliceCell as a slice of Cells.

View a Cell of a slice as a SliceCell.

Returns a raw pointer to the underlying data in this SliceCell.

Unwraps a boxed SliceCell into a slice.

Wraps a boxed slice in a SliceCell.

Wraps a reference-counted slice in a SliceCell, if it is uniquely owned.

Unwraps a reference-counted SliceCell into an slice, if it is uniquely owned.

Unwraps a uniquely borrowed SliceCell into a slice.

Wraps a uniquely borrowed slice in a SliceCell.

Returns the length of the SliceCell.

Divide one SliceCell into two at an index.

Panics if mid > self.len().

See slice::split_at

Divide one mutable SliceCell into two at an index.

Panics if mid > self.len().

See slice::split_at_mut

Returns the first and all the rest of the elements of the SliceCell, or None if it is empty.

See slice::split_first

Returns the first and all the rest of the elements of the SliceCell, or None if it is empty.

See slice::split_first_mut

Returns the last and all the rest of the elements of the SliceCell, or None if it is empty.

See slice::split_last

Returns the last and all the rest of the elements of the SliceCell, or None if it is empty.

See slice::split_last_mut

Copies all elements from src into self, using a memcpy.

The length of src must be the same as self.

See slice::copy_from_slice.

Clones all elements from src into self.

The length of src must be the same as self.

See slice::copy_from_slice.

Take all elements from this SliceCell into a mutable slice, leaving T::default() in each cell

Take all elements from this SliceCell into a newly allocated Vec<T>, leaving T::default() in each cell.

Copy all elements from this SliceCell into a mutable slice.

Copy all elements from this SliceCell into a newly allocated Vec<T>.

Swaps two elements in the slice.

See <[T]>::swap.

Fills self with elements by cloning value.

See also: <[T]>::fill.

Fills self with elements returned by calling a closure repeatedly.

See also: <[T]>::fill_with.

Replacement for TryFrom impl, since Rc is not fundamental

N should not be 0.

Splits the slice into a slice of N-element arrays, starting at the beginning of the slice, and a remainder slice with length strictly less than N.

N should not be 0.

Splits the slice into a slice of N-element arrays, starting at the end of the slice, and a remainder slice with length strictly less than N.

N should not be 0.

Splits the slice into a slice of N-element arrays, starting at the beginning of the slice, and a remainder slice with length strictly less than N.

N should not be 0.

Splits the slice into a slice of N-element arrays, starting at the end of the slice, and a remainder slice with length strictly less than N.